@@ -22,26 +22,27 @@ class DSHelper(BaseSqlHelper):
         初始化sql工具
         :param pool_name: 连接池名称
         """
-        self.pool, self.dialect = options.database[pool_name]
-        if self.dialect == "postgresql":
+        self.pool, self.conn_info = options.database[pool_name]
+        clazz = None
+        if self.conn_info.dialect == "postgresql":
             # self.db_helper = PostgresqlHelper(self.pool)
             clazz = getattr(__import__("lesscode.db.postgresql.postgresql_helper", fromlist="PostgresqlHelper"),
                             "PostgresqlHelper")
-        elif self.dialect == "mysql":
+        elif self.conn_info.dialect == "mysql":
             # self.db_helper = MysqlHelper(self.pool)
             clazz = getattr(__import__("lesscode.db.mysql.mysql_helper", fromlist="MysqlHelper"), "MysqlHelper")
             # 执行用例
             self.db_helper = clazz(self.pool)
-        elif self.dialect == "mongodb":
+        elif self.conn_info.dialect == "mongodb":
             clazz = getattr(__import__("lesscode.db.mongodb.mongodb_helper", fromlist="MongodbHelper"), "MongodbHelper")
             # self.db_helper = MongodbHelper(self.pool)
-        elif self.dialect == "elasticsearch":
+        elif self.conn_info.dialect == "elasticsearch":
             clazz = getattr(
                 __import__("lesscode.db.elasticsearch.elasticsearch_helper", fromlist="ElasticsearchHelper"),
                 "ElasticsearchHelper")
-        elif self.dialect == "esapi":
+        elif self.conn_info.dialect == "esapi":
             clazz = getattr(__import__("lesscode.db.es.es_helper", fromlist="EsHelper"), "EsHelper")
-        elif self.dialect == "redis":
+        elif self.conn_info.dialect == "redis":
             clazz = getattr(
                 __import__("lesscode.db.redis.redis_helper", fromlist="RedisHelper"),
                 "RedisHelper")
